function meff(obs::Vector{uwreal}, plat::Vector{Int64}; pl::Bool=true, data::Bool=false )     
    dim = length(obs)                                                                                    
    aux = log.(obs[2:dim-2] ./ obs[3:dim-1])     
    mass = plat_av(aux, plat)                                                                            
    uwerr(mass)                       
    if pl == true
        x = 1:length(aux)
        y = value.(aux)
        dy = err.(aux)
        v = value(mass)
        e = err(mass)
        
        figure()
        fill_between(plat[1]:plat[2], v-e, v+e, color="green", alpha=0.75)
        errorbar(x, y, dy, fmt="x", color="black")
        ylabel(L"$m_\mathrm{eff}$")
        xlabel(L"$x_0$")
        display(gcf())
    end                                                  
    if data == false                   
        return mass                                        
    else               
        return (mass, aux)     
    end                    
end   
meff(corr::Corr, plat::Vector{Int64}; pl::Bool=true, data::Bool=false) = 
    meff(corr.obs, plat, pl=pl, data=data)

## Decay constants                                                                                       
#TODO: test 
function dec_const_pcvc(obs::Vector{uwreal}, plat::Vector{Int64}, m::uwreal, mu::Vector{Float64}, y0::Int64 ; pl::Bool=true, data::Bool=false)
    """
    compute the decay constant when the source is far from the boundaries
    """
    corr_pp = obs[2:end-1]
    dim = length(corr_pp)
                                                                 
    aux = exp.((collect(1:dim) .- y0 ) .* [m for k in 1:dim])
    R = (aux .* corr_pp).^0.5
    R_av = plat_av(R, plat)
    f = sqrt(2) * (mu[1] + mu[2]) *R_av / m^1.5
    uwerr(f)
    if pl == true
        uwerr(R_av)
        v = value(R_av)
        e = err(R_av)                                
        uwerr.(R)
        figure()
        fill_between(plat[1]:plat[2], v-e, v+e, color="green", alpha=0.75)                                            
        errorbar(1:length(R), value.(R), err.(R), fmt="x", color="black")
        ylabel(L"$R$")
        xlabel(L"$x_0$")
        display(gcf())          
    end 
    if data == false
        return f
    else
        return (f, R)                   
    end 
end 
dec_const_pcvc(corr::Corr, plat::Vector{Int64}, m::uwreal; pl::Bool=true, data::Bool=false) =
    dec_const_pcvc(corr.obs, plat, m, corr.mu, corr.y0, pl=pl, data=data)
